@@ -1,6 +1,6 @@
 'VisiData: a curses interface for exploring and arranging tabular data'
 
-__version__ = '2.10.1'
+__version__ = '2.11'
 __version_info__ = 'VisiData v' + __version__
 __author__ = 'Saul Pwanson <vd@saul.pw>'
 __status__ = 'Production/Stable'
@@ -12,10 +12,12 @@ class EscapeException(BaseException):
     pass
 
 
-def addGlobals(g):
-    '''Update the VisiData globals dict with items from *g*, which is a mapping of names to functions.
+def addGlobals(*args, **kwargs):
+    '''Update the VisiData globals dict with items from *args* and *kwargs*, which are mappings of names to functions.
     Importers can call ``addGlobals(globals())`` to have their globals accessible to execstrings.'''
-    globals().update(g)
+    for g in args:
+        globals().update(g)
+    globals().update(kwargs)
 
 
 def getGlobals():
@@ -61,28 +63,33 @@ from .path import *
 import visidata._input
 import visidata.movement
 
+import visidata.type_currency
+import visidata.type_date
+import visidata.type_floatsi
+
 import visidata._urlcache
 import visidata.selection
 import visidata.loaders.tsv
 import visidata.pyobj
 import visidata.loaders.json
 import visidata._open
+import visidata.metasheets
+import visidata.cmdlog
 import visidata.save
 import visidata.clipboard
+import visidata.sysedit
 import visidata.slide
 import visidata.search
 import visidata.expr
 
 import visidata.menu
 import visidata.choose
-import visidata.metasheets
 import visidata.join
 import visidata.aggregators
 import visidata.describe
 import visidata.pivot
 import visidata.freqtbl
 import visidata.melt
-import visidata.cmdlog
 import visidata.freeze
 import visidata.regex
 import visidata.canvas
@@ -105,6 +112,7 @@ import visidata.misc
 import visidata.memory
 import visidata.macros
 import visidata.macos
+import visidata.repeat
 
 import visidata.loaders.csv
 import visidata.loaders.archive
@@ -148,6 +156,8 @@ import visidata.loaders.lsv
 import visidata.loaders.arrow
 import visidata.loaders.parquet
 
+import visidata.loaders.vdx
+
 import visidata.form
 
 import visidata.ddwplay
