@@ -25,6 +25,11 @@ class LazyChainMap:
     def keys(self):
         return list(self.objs.keys())  # sum(set(dir(obj)) for obj in self.objs))
 
+    def get(self, key, default=None):
+        if key in self.locals:
+            return self.locals[key]
+        return self.objs.get(key, default)
+
     def clear(self):
         self.locals.clear()
 
@@ -73,6 +78,19 @@ class DrawablePane(Extensible):
             return True
 
 
+class _dualproperty:
+    'Return *obj_method* or *cls_method* depending on whether property is on instance or class.'
+    def __init__(self, obj_method, cls_method):
+        self._obj_method = obj_method
+        self._cls_method = cls_method
+
+    def __get__(self, obj, objtype=None):
+        if obj is None:
+            return self._cls_method(objtype)
+        else:
+            return self._obj_method(obj)
+
+
 class BaseSheet(DrawablePane):
     'Base class for all sheet types.'
     _rowtype = object    # callable (no parms) that returns new empty item
@@ -81,13 +99,13 @@ class BaseSheet(DrawablePane):
     precious = True      # False for a few discardable metasheets
     defer = False        # False for not deferring changes until save
 
-    @visidata.classproperty
-    def class_options(cls):
+    def _obj_options(self):
+        return vd.OptionsObject(vd._options, obj=self)
+
+    def _class_options(cls):
         return vd.OptionsObject(vd._options, obj=cls)
 
-    @property
-    def options(self):
-        return vd.OptionsObject(vd._options, obj=self)
+    class_options = options = _dualproperty(_obj_options, _class_options)
 
     def __init__(self, *names, **kwargs):
         self._name = None   # initial cache value necessary for self.options
@@ -232,11 +250,11 @@ class BaseSheet(DrawablePane):
 
     @property
     def cursorRow(self):
-        'The row object at the row cursor.  Overrideable.'
+        'The row object at the row cursor.  Overridable.'
         return None
 
     def checkCursor(self):
-        'Check cursor and fix if out-of-bounds.  Overrideable.'
+        'Check cursor and fix if out-of-bounds.  Overridable.'
         pass
 
     def checkCursorNoExceptions(self):
@@ -251,17 +269,17 @@ class BaseSheet(DrawablePane):
 
     @property
     def sidebar(self):
-        'Default implementation just returns set value.  Overrideable.'
+        'Default implementation just returns set value.  Overridable.'
         return self._sidebar
 
     @sidebar.setter
     def sidebar(self, v):
-        'Default implementation just sets value.  Overrideable.'
+        'Default implementation just sets value.  Overridable.'
         self._sidebar = v
 
     @property
     def sidebar_title(self):
-        'Default implementation returns fixed value.  Overrideable.'
+        'Default implementation returns fixed value.  Overridable.'
         return 'sidebar'
 
 
