@@ -1,4 +1,5 @@
 from visidata import *
+import collections
 
 
 @Column.api
@@ -8,7 +9,7 @@ def resetCache(col):
 
 
 @Sheet.api
-def StaticColumn(sheet, col):
+def freeze_col(sheet, col):
     frozencol = SettableColumn(col.name+'_frozen')
     state = col.__getstate__()
     state.pop('name')
