@@ -1,8 +1,11 @@
+import collections
+
 from visidata import *
 
 
-option('confirm_overwrite', True, 'whether to prompt for overwrite confirmation on save')
-option('safe_error', '#ERR', 'error string to use while saving', replay=True)
+vd.option('confirm_overwrite', True, 'whether to prompt for overwrite confirmation on save')
+vd.option('safe_error', '#ERR', 'error string to use while saving', replay=True)
+vd.option('disp_formatter', 'generic', 'formatter to use for display and saving', replay=True)
 
 @Sheet.api
 def safe_trdict(vs):
@@ -28,7 +31,8 @@ def iterdispvals(sheet, *cols, format=False):
     for col in cols:
         transformers[col] = [ col.type ]
         if format:
-            transformers[col].append(col.format)
+            formatMaker = getattr(col, 'formatter_'+(col.formatter or sheet.options.disp_formatter))
+            transformers[col].append(formatMaker(col._formatdict))
         trdict = sheet.safe_trdict()
         if trdict:
             transformers[col].append(lambda v,trdict=trdict: v.translate(trdict))
@@ -97,29 +101,34 @@ def save_cols(vd, cols):
     vd.saveSheets(path, vs, confirm_overwrite=options.confirm_overwrite)
 
 
-@VisiData.global_api
+@VisiData.api
 def saveSheets(vd, givenpath, *vsheets, confirm_overwrite=False):
     'Save all *vsheets* to *givenpath*.'
 
     filetype = givenpath.ext or options.save_filetype
 
+    vd.clearCaches()
+
     savefunc = getattr(vsheets[0], 'save_' + filetype, None) or getattr(vd, 'save_' + filetype, None)
 
     if savefunc is None:
-        savefunc = getattr(vd, 'save_' + options.save_filetype, None) or vd.fail('no function to save as type %s' % filetype)
-        vd.warning(f'save for {filetype} unavailable, using {options.save_filetype}')
+        vd.fail(f'no function to save as {filetype}')
 
     if givenpath.exists() and confirm_overwrite:
-        confirm("%s already exists. overwrite? " % givenpath.given)
+        vd.confirm("%s already exists. overwrite? " % givenpath.given)
 
     vd.status('saving %s sheets to %s as %s' % (len(vsheets), givenpath.given, filetype))
 
     if not givenpath.given.endswith('/'):  # forcibly specify save individual files into directory by ending path with /
         for vs in vsheets:
             vs.hasBeenModified = False
+        # savefuncs(vd, p, *vsheets) will have 2 argcount (*vsheets does not get counted as an arg)
+        # savefuncs(vd, p, vs) will have 3 argcount (vs counts as an arg, along with vd, path)
+        if savefunc.__code__.co_argcount == 3 and len(vsheets) > 1:
+            vd.fail(f'cannot save multiple {filetype} sheets to non-dir')
         return vd.execAsync(savefunc, givenpath, *vsheets)
 
-    # more than one sheet; either no specific multisave for save filetype, or path ends with /
+    # path is a dir
 
     # save as individual files in the givenpath directory
     try:
@@ -135,7 +144,24 @@ def saveSheets(vd, givenpath, *vsheets, confirm_overwrite=False):
             p = Path((givenpath / vs.name).with_suffix('.'+filetype))
             savefunc(p, vs)
             vs.hasBeenModified = False
-    return vd.execAsync(_savefile, vsheets, givenpath, savefunc, filetype)
+    return vd.execAsync(_savefiles, vsheets, givenpath, savefunc, filetype)
+
+
+@VisiData.api
+def save_zip(vd, p, *vsheets):
+    vd.clearCaches()
+
+    import tempfile
+    import zipfile
+    with tempfile.TemporaryDirectory() as tmpdir:
+        with zipfile.ZipFile(str(p), 'w', zipfile.ZIP_DEFLATED, allowZip64=True, compresslevel=9) as zfp:
+            for vs in Progress(vsheets):
+                filetype = vs.options.save_filetype
+                tmpp = Path(f'{tmpdir}{vs.name}.{filetype}')
+                savefunc = getattr(vs, 'save_' + filetype, None) or getattr(vd, 'save_' + filetype, None)
+                savefunc(tmpp, vs)
+                zfp.write(tmpp, f'{vs.name}.{vs.options.save_filetype}')
+    vd.status('%s save finished' % p)
 
 
 @VisiData.api
@@ -150,8 +176,17 @@ def save_txt(vd, p, *vsheets):
     vd.status('%s save finished' % p)
 
 
-Sheet.addCommand('^S', 'save-sheet', 'vd.saveSheets(inputPath("save to: ", value=getDefaultSaveName()), sheet, confirm_overwrite=options.confirm_overwrite)', 'save current sheet to filename in format determined by extension (default .tsv)')
+@BaseSheet.api
+def rootSheet(sheet):
+    r = sheet
+    while isinstance(r.source, BaseSheet):
+        r = r.source
+
+    return r
+
+BaseSheet.addCommand('^S', 'save-sheet', 'vd.saveSheets(inputPath("save to: ", value=getDefaultSaveName()), sheet, confirm_overwrite=options.confirm_overwrite)', 'save current sheet to filename in format determined by extension (default .tsv)')
+BaseSheet.addCommand('', 'save-source', 'vd.saveSheets(rootSheet().source, rootSheet(), confirm_overwrite=options.confirm_overwrite)', 'save root sheet to its source')
 BaseSheet.addCommand('g^S', 'save-all', 'vd.saveSheets(inputPath("save all sheets to: "), *vd.stackedSheets, confirm_overwrite=options.confirm_overwrite)', 'save all sheets to given file or directory)')
-IndexSheet.addCommand('g^S', 'save-selected', 'vd.saveSheets(inputPath("save %d sheets to: " % nSelectedRows, value=str(source)), *selectedRows, confirm_overwrite=options.confirm_overwrite)', 'save all selected sheets to given file or directory')
+IndexSheet.addCommand('g^S', 'save-selected', 'vd.saveSheets(inputPath("save %d sheets to: " % nSelectedRows, value="_".join(getattr(vs, "name", None) or "blank" for vs in selectedRows)), *selectedRows, confirm_overwrite=options.confirm_overwrite)', 'save all selected sheets to given file or directory')
 Sheet.addCommand('', 'save-col', 'save_cols([cursorCol])', 'save current column only to filename in format determined by extension (default .tsv)')
 Sheet.addCommand('', 'save-col-keys', 'save_cols(keyCols + [cursorCol])', 'save key columns and current column to filename in format determined by extension (default .tsv)')
